@@ -38,7 +38,7 @@ opts = [
 name = 'ec2'
 
 
-class Collector(object):
+class Collector:
     def __init__(self, requests_impl=common.requests):
         self._requests_impl = requests_impl
         self.session = requests_impl.Session()
