@@ -21,7 +21,6 @@ import sys
 import tempfile
 from unittest import mock
 
-import extras
 import fixtures
 from oslo_config import cfg
 import testtools
@@ -60,7 +59,7 @@ def _setup_local_metadata(test_case):
 class TestCollect(testtools.TestCase):
 
     def setUp(self):
-        super(TestCollect, self).setUp()
+        super().setUp()
         self.useFixture(fixtures.FakeLogger())
         collect.setup_conf()
         self.addCleanup(cfg.CONF.reset)
@@ -86,8 +85,8 @@ class TestCollect(testtools.TestCase):
         }
         with mock.patch.object(config_drive, 'get_metadata') as gm:
             gm.return_value = {}
-            return collect.__main__(args=fake_args,
-                                    collector_kwargs_map=collector_kwargs_map)
+            return collect.main(args=fake_args,
+                                collector_kwargs_map=collector_kwargs_map)
 
     def _fake_popen_call_main(self, occ_args):
         calls = []
@@ -318,8 +317,8 @@ class TestCollect(testtools.TestCase):
 
         self.useFixture(fixtures.MonkeyPatch('time.sleep', fake_sleep))
         try:
-            collect.__main__(['os-collect-config', 'heat_local', '-i', '10',
-                              '-c', 'true'])
+            collect.main(['os-collect-config', 'heat_local', '-i', '10',
+                          '-c', 'true'])
         except ExpectedException:
             pass
 
@@ -328,8 +327,8 @@ class TestCollect(testtools.TestCase):
             raise Exception(cfg.CONF.command)
 
         self.useFixture(fixtures.MonkeyPatch('time.sleep', fake_sleep))
-        collect.__main__(['os-collect-config', 'heat_local', '--config-file',
-                          '/dev/null', '-i', '10'])
+        collect.main(['os-collect-config', 'heat_local', '--config-file',
+                      '/dev/null', '-i', '10'])
 
     def test_main_min_polling_interval(self):
         class ExpectedException(Exception):
@@ -340,7 +339,7 @@ class TestCollect(testtools.TestCase):
                 raise ExpectedException
 
         self.useFixture(fixtures.MonkeyPatch('time.sleep', fake_sleep))
-        self.assertRaises(ExpectedException, collect.__main__,
+        self.assertRaises(ExpectedException, collect.main,
                           ['os-collect-config', 'heat_local', '-i', '10',
                            '--min-polling-interval', '20', '-c', 'true'])
 
@@ -348,9 +347,9 @@ class TestCollect(testtools.TestCase):
     @mock.patch('random.randrange')
     def test_main_with_splay(self, randrange_mock, sleep_mock):
         randrange_mock.return_value = 4
-        collect.__main__(args=['os-collect-config', 'heat_local', '-i', '10',
-                               '--min-polling-interval', '20', '-c', 'true',
-                               '--print', '--splay', '29'])
+        collect.main(args=['os-collect-config', 'heat_local', '-i', '10',
+                           '--min-polling-interval', '20', '-c', 'true',
+                           '--print', '--splay', '29'])
         randrange_mock.assert_called_with(0, 29)
         sleep_mock.assert_called_with(4)
 
@@ -358,7 +357,7 @@ class TestCollect(testtools.TestCase):
 class TestCollectAll(testtools.TestCase):
 
     def setUp(self):
-        super(TestCollectAll, self).setUp()
+        super().setUp()
         self.log = self.useFixture(fixtures.FakeLogger())
         collect.setup_conf()
         self.cache_dir = self.useFixture(fixtures.TempDir())
@@ -423,8 +422,8 @@ class TestCollectAll(testtools.TestCase):
         (changed_keys, paths) = self._call_collect_all(
             store=True, collector_kwargs_map=collector_kwargs_map)
         if expected_changed is None:
-            expected_changed = set(['heat_local', 'cfn', 'ec2',
-                                    'heat', 'local', 'request', 'zaqar'])
+            expected_changed = {'heat_local', 'cfn', 'ec2',
+                                'heat', 'local', 'request', 'zaqar'}
         self.assertEqual(expected_changed, changed_keys)
         self.assertThat(paths, matchers.IsInstance(list))
         for path in paths:
@@ -451,9 +450,9 @@ class TestCollectAll(testtools.TestCase):
                 'discover_class': test_heat.FakeKeystoneDiscover
             },
         }
-        expected_changed = set((
+        expected_changed = {
             'heat_local', 'ec2', 'cfn', 'heat', 'local', 'request',
-            'dep-name1', 'dep-name2', 'dep-name3', 'zaqar'))
+            'dep-name1', 'dep-name2', 'dep-name3', 'zaqar'}
         self._test_collect_all_store(collector_kwargs_map=soft_config_map,
                                      expected_changed=expected_changed)
 
@@ -557,14 +556,14 @@ class TestConf(testtools.TestCase):
     def test_setup_conf(self):
         collect.setup_conf()
         self.assertEqual('/var/lib/os-collect-config', cfg.CONF.cachedir)
-        self.assertTrue(extras.safe_hasattr(cfg.CONF, 'ec2'))
-        self.assertTrue(extras.safe_hasattr(cfg.CONF, 'cfn'))
+        self.assertTrue(hasattr(cfg.CONF, 'ec2'))
+        self.assertTrue(hasattr(cfg.CONF, 'cfn'))
 
 
 class TestHup(testtools.TestCase):
 
     def setUp(self):
-        super(TestHup, self).setUp()
+        super().setUp()
         self.log = self.useFixture(fixtures.FakeLogger())
 
         def fake_closerange(low, high):
@@ -589,7 +588,7 @@ class TestHup(testtools.TestCase):
 
 class TestFileHash(testtools.TestCase):
     def setUp(self):
-        super(TestFileHash, self).setUp()
+        super().setUp()
 
         # Deletes tempfiles during teardown
         self.useFixture(fixtures.NestedTempfile())
