@@ -21,7 +21,7 @@ from oslo_config import cfg
 from oslo_config import fixture as config_fixture
 import testtools
 from testtools import matchers
-from zaqarclient.queues.v1 import message
+from zaqarclient.queues.v2 import message
 from zaqarclient import transport
 from zaqarclient.transport import response
 
@@ -47,13 +47,13 @@ class FakeKeystoneClientWebsocket(test_heat.FakeKeystoneClient):
         return 'ws://127.0.0.1:9000/'
 
 
-class FakeZaqarClient(object):
+class FakeZaqarClient:
 
     def __init__(self, testcase):
         self._test = testcase
 
     def Client(self, endpoint, conf, version):
-        self._test.assertEqual(1.1, version)
+        self._test.assertEqual(2, version)
         self._test.assertEqual('http://192.0.2.1:8888/', endpoint)
         return self
 
@@ -63,7 +63,7 @@ class FakeZaqarClient(object):
         return FakeQueue()
 
 
-class FakeZaqarWebsocketClient(object):
+class FakeZaqarWebsocketClient:
 
     def __init__(self, options, messages=None, testcase=None):
         self._messages = messages
@@ -88,20 +88,20 @@ class FakeZaqarWebsocketClient(object):
         pass
 
 
-class FakeQueue(object):
+class FakeQueue:
 
     def pop(self):
         return iter([message.Message(
             queue=self, ttl=10, age=10, body=test_heat.META_DATA, href='')])
 
 
-class FakeZaqarClientSoftwareConfig(object):
+class FakeZaqarClientSoftwareConfig:
 
     def __init__(self, testcase):
         self._test = testcase
 
     def Client(self, endpoint, conf, version):
-        self._test.assertEqual(1.1, version)
+        self._test.assertEqual(2, version)
         self._test.assertEqual('http://192.0.2.1:8888/', endpoint)
         return self
 
@@ -111,7 +111,7 @@ class FakeZaqarClientSoftwareConfig(object):
         return FakeQueueSoftwareConfig()
 
 
-class FakeQueueSoftwareConfig(object):
+class FakeQueueSoftwareConfig:
 
     def pop(self):
         return iter([message.Message(
@@ -121,7 +121,7 @@ class FakeQueueSoftwareConfig(object):
 
 class TestZaqar(testtools.TestCase):
     def setUp(self):
-        super(TestZaqar, self).setUp()
+        super().setUp()
         self.log = self.useFixture(fixtures.FakeLogger())
         self.useFixture(fixtures.NestedTempfile())
         collect.setup_conf()
